YARP 2.3.63 (2014-07-14)                                              {#v2_3_63}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.61...v2.3.62`):

```
    83	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    73	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    32	Alberto Cardellino <alberto.cardellino@iit.it>
    13	Ali Paikan <ali.paikan@iit.it>
    13	Lorenzo Natale <lorenzo.natale@iit.it>
    13	Ugo Pattacini <ugo.pattacini@iit.it>
    11	Marco Randazzo <marco.randazzo@iit.it>
    10	Elena Ceseracciu <elena.ceseracciu@iit.it>
     6	Konstantinos Theofilis <kostas@ams.eng.osaka-u.ac.jp>
     5	Silvio Traversaro <silvio.traversaro@iit.it>
     4	Francesco Romano <francesco.romano@iit.it>
     4	Mirko Ferrati <mirko8787@gmail.com>
     3	Alessio Rocchi <alessio.rocchi@iit.it>
     3	Francesco Giovannini <francesco.giovannini@iit.it>
     2	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Plinio Moreno <plinio@isr.tecnico.ulisboa.pt>
     1	Valentina Gaggero <valentina.gaggero@iit.it>
     1	YARP Developers <yarp0-devel@lists.sourceforge.net>
```
